==> opensearch-dashboards-3.2.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/plugins/vis_type_timeseries/server/lib/vis_data/helpers/get_sibling_agg_value.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSiblingAggValue = void 0;
var _lodash = _interopRequireDefault(require("lodash"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const getSiblingAggValue = (row, metric) => {
  let key = metric.type.replace(/_bucket$/, '');
  if (key === 'std_deviation' && _lodash.default.includes(['upper', 'lower'], metric.mode)) {
    key = `std_deviation_bounds.${metric.mode}`;
  }
  return _lodash.default.get(row, `${metric.id}.${key}`);
};
exports.getSiblingAggValue = getSiblingAggValue;

==> opensearch-dashboards-3.4.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/plugins/vis_type_timeseries/server/lib/vis_data/helpers/get_sibling_agg_value.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSiblingAggValue = void 0;
var _lodash = _interopRequireDefault(require("lodash"));
var _safe_get = require("./safe_get");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const getSiblingAggValue = (row, metric) => {
  let key = metric.type.replace(/_bucket$/, '');
  if (key === 'std_deviation' && _lodash.default.includes(['upper', 'lower'], metric.mode)) {
    key = `std_deviation_bounds.${metric.mode}`;
  }
  return (0, _safe_get.safeGet)(row, `${metric.id}.${key}`);
};
exports.getSiblingAggValue = getSiblingAggValue;
